Struct PciRootBridgeIoProtocol
Source #[repr(C)]
pub struct PciRootBridgeIoProtocol {Show 16 fields
pub parent_handle: Handle,
pub poll_mem: unsafe extern "efiapi" fn(this: *mut Self, width: PciRootBridgeIoProtocolWidth, address: u64, mask: u64, value: u64, delay: u64, result: *mut u64) -> Status,
pub poll_io: unsafe extern "efiapi" fn(this: *mut Self, width: PciRootBridgeIoProtocolWidth, address: u64, mask: u64, value: u64, delay: u64, result: *mut u64) -> Status,
pub mem: PciRootBridgeIoAccess,
pub io: PciRootBridgeIoAccess,
pub pci: PciRootBridgeIoAccess,
pub copy_mem: unsafe extern "efiapi" fn(this: *mut Self, width: PciRootBridgeIoProtocolWidth, dest_addr: u64, src_addr: u64, count: usize) -> Status,
pub map: unsafe extern "efiapi" fn(this: *const Self, operation: PciRootBridgeIoProtocolOperation, host_addr: *const c_void, num_bytes: *mut usize, device_addr: *mut PhysicalAddress, mapping: *mut *mut c_void) -> Status,
pub unmap: unsafe extern "efiapi" fn(this: *const Self, mapping: *const c_void) -> Status,
pub allocate_buffer: unsafe extern "efiapi" fn(this: *const Self, alloc_ty: AllocateType, memory_ty: MemoryType, pages: usize, host_addr: *mut *const c_void, attributes: u64) -> Status,
pub free_buffer: unsafe extern "efiapi" fn(this: *const Self, pages: usize, host_addr: *const c_void) -> Status,
pub flush: unsafe extern "efiapi" fn(this: *mut Self) -> Status,
pub get_attributes: unsafe extern "efiapi" fn(this: *const Self, supports: *mut u64, attributes: *mut u64) -> Status,
pub set_attributes: unsafe extern "efiapi" fn(this: *mut Self, attributes: u64, resource_base: *mut u64, resource_length: *mut u64) -> Status,
pub configuration: unsafe extern "efiapi" fn(this: *const Self, resources: *mut *const c_void) -> Status,
pub segment_number: u32,
}
parent_handle: Handle
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.